History
=======

1.0.0 (2010-09-05)
------------------
* Featureset complete
* Public release of showme to PyPi
* Cleanup of project (removal of globals/locals)


0.0.5 (2010-09-05)
------------------
* @showme.time support (simple but big feature)
* Color output added (via vendorized Colorama)


0.0.4 (2010-09-04)
------------------
* Epic @showme.trace decorator written
* @showme.docs support


0.0.3 (2010-09-01)
------------------
* General configuration in place
* @showme.cputime support
* Vendorization of decorator decorator
